![Studio Lint Test](https://github.com/yconst/tinymovr/workflows/Tinymovr%20Studio%20Lint%2FTest/badge.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Tinymovr Studio Python

This is the Python client library and application that allows easy interfacing with the Tinymovr motor control board.

### Installing using pip

This is the most straightforward method to install Tinymovr studio and have access to hardware. We use pip3 to ensure Tinymovr is installed using Python 3 (required).

    pip3 install tinymovr

### Installing using git clone

First clone the Tinymovr repo to a local directory:

    git clone https://github.com/yconst/Tinymovr

Then cd to the cloned repo directory and install in developer mode:

    cd Tinymovr/studio/Python
    pip3 install -e .

### Launching the GUI app

    tinymovr

### Launching the command line app

    tinymovr_cli

## Getting Help

[Full documentation is available at Readthedocs](https://tinymovr.readthedocs.io).

Please visit the [Discussions Page](https://github.com/tinymovr/Tinymovr/discussions) and the [Discord Server](https://discord.gg/vNvmpfthug) to ask any questions. If you are unable to find an answer to your question, you are welcome to [start a new discussion](https://github.com/tinymovr/Tinymovr/discussions/new/choose) or ask away at [our Discord server](https://discord.gg/vNvmpfthug).

If you would like to propose a feature or think you have found a bug, [open a new issue](https://github.com/tinymovr/Tinymovr/issues/new).

### More information

[Website and Store](https://tinymovr.com)

[Documentation](https://tinymovr.readthedocs.io)

